@@ -63,7 +63,18 @@ class training_class():
         self.visualize_images_per_epoch = False
         self.save_test_images_per_epoch = False
         self.set_params(params_dict)
-
+    def print_params(self):
+        print("{:<20} {:<20} ".format('datasets_path:', self.datasets_path))
+        print("{:<20} {:<10} {:<10} {:<10} {:<10} {:<10}".format('train_datasets_size:', self.train_datasets_size, 'pth_dir:',
+                                                   self.pth_dir,'batch_size:', self.batch_size))
+        print("{:<20} {:<10} {:<10} {:<10} {:<10} {:<10}".format('overlap_factor:', self.overlap_factor,'fmap:',self.fmap, 'lr:',self.lr))
+        print("{:<20} {:<10} {:<10} {:<10} {:<10} {:<10}".format('n_epochs:', self.n_epochs, 'GPU:',self.GPU, 'ngpu:',self.ngpu))
+        print("{:<10} {:<10} {:<10} {:<10} {:<10} {:<10}".format('patch_t:', self.patch_t, 'patch_x:',self.patch_x, 'patch_y:',self.patch_y))
+        print("{:<10} {:<10} {:<10} {:<10} {:<10} {:<10}".format('patch_t:', self.gap_t, 'gap_x:',self.gap_x, 'gap_y:',self.gap_y))
+        print("{:<10} {:<10} {:<10} {:<10} {:<10} {:<10}".format('Adam b1:', self.b1, 'Adam b2:',self.b2, 'num_workers:',self.num_workers))
+        print("{:<10} {:<7} {:<15} {:<6} {:<7} {:<10}".format('scale_factor:', self.scale_factor, 'select_img_num:',self.select_img_num, 'test_datasize:',self.test_datasize))
+        print('visualize_images_per_epoch:',self.visualize_images_per_epoch,end="\t")
+        print('save_test_images_per_epoch:',self.save_test_images_per_epoch,end="\t")
     def run(self):
         """
         General function for training DeepCAD network.
@@ -115,6 +126,7 @@ class training_class():
         self.batch_size = self.ngpu                                 # By default, the batch size is equal to the number of GPU for minimal memory consumption
         print('\033[1;31mTraining parameters -----> \033[0m')
         print(self.__dict__)
+        # self.print_params()
 
     def initialize_network(self):
         """
@@ -316,9 +328,9 @@ class training_class():
                     self.save_model(epoch, iteration)
                     # Start inference using the denoise model at the end of every epoch (optional)
                     if (self.visualize_images_per_epoch | self.save_test_images_per_epoch):
-                        print('\033[1;31mTesting epoch {} model on the first noisy file -----> \033[0m'.format(epoch))
+                        print('Testing epoch {} model on the first noisy file ----->'.format(epoch))
                         self.test(epoch, iteration)
-        print('Train finished. Save all model to disk.')
+        print('Train finished. Save all models to disk.')
 
     def save_model(self, epoch, iteration):
         """
@@ -407,10 +419,10 @@ class training_class():
         # Stitching finish
         output_img = denoise_img.squeeze().astype(np.float32) * self.scale_factor
         del denoise_img
-        print('\033[1;31mDisplaying the first denoise file -----> \033[0m')
 
         # Normalize and display inference image
         if (self.visualize_images_per_epoch):
+            print('Displaying the first denoise file ----->')
             display_length = self.test_datasize
             test_img_display(output_img, display_length=display_length, norm_min_percent=1, norm_max_percent=98)
 
